--- chrome/browser/renderer_host/browser_render_process_host.cc
+++ chrome/browser/renderer_host/browser_render_process_host.cc
@@ -63,7 +63,7 @@
 #if defined(OS_WIN)
 #include "app/win_util.h"
 #include "chrome/browser/sandbox_policy.h"
-#elif defined(OS_LINUX)
+#elif defined(OS_NIX)
 #include "base/singleton.h"
 #include "chrome/browser/crash_handler_host_linux.h"
 #include "chrome/browser/zygote_host_linux.h"
@@ -245,7 +245,7 @@ BrowserRenderProcessHost::~BrowserRenderProcessHost() {
 
   if (process_.handle() && !run_renderer_in_process()) {
     if (zygote_child_) {
-#if defined(OS_LINUX)
+#if defined(OS_NIX)
       Singleton<ZygoteHost>()->EnsureProcessTerminated(process_.handle());
 #endif
     } else {
@@ -330,11 +330,11 @@ bool BrowserRenderProcessHost::Init(bool is_extensions_process) {
     in_process_renderer_.reset(new RendererMainThread(channel_id));
 
     base::Thread::Options options;
-#if !defined(OS_LINUX)
+#if !defined(USE_X11)
     // In-process plugins require this to be a UI message loop.
     options.message_loop_type = MessageLoop::TYPE_UI;
 #else
-    // We can't have multiple UI loops on Linux, so we don't support
+    // We can't have multiple UI loops on X, so we don't support
     // in-process plugins.
     options.message_loop_type = MessageLoop::TYPE_DEFAULT;
 #endif
@@ -608,7 +608,7 @@ base::ProcessHandle BrowserRenderProcessHost::ExecuteRenderer(
 base::ProcessHandle BrowserRenderProcessHost::ExecuteRenderer(
     CommandLine* cmd_line,
     bool has_cmd_prefix) {
-#if defined(OS_LINUX)
+#if defined(OS_NIX)
   // On Linux, normally spawn processes with zygotes. We can't do this when
   // we're spawning child processes through an external program (i.e. there is a
   // command prefix) like GDB so fall through to the POSIX case then.
@@ -625,7 +625,7 @@ base::ProcessHandle BrowserRenderProcessHost::ExecuteRenderer(
     zygote_child_ = true;
     return Singleton<ZygoteHost>()->ForkRenderer(cmd_line->argv(), mapping);
   }
-#endif  // defined(OS_LINUX)
+#endif  // defined(OS_NIX)
 
   // NOTE: This code is duplicated with plugin_process_host.cc, but
   // there's not a good place to de-duplicate it.
@@ -633,7 +633,7 @@ base::ProcessHandle BrowserRenderProcessHost::ExecuteRenderer(
   const int ipcfd = channel_->GetClientFileDescriptor();
   fds_to_map.push_back(std::make_pair(ipcfd, kPrimaryIPCChannel + 3));
 
-#if defined(OS_LINUX)
+#if defined(OS_NIX)
   // On Linux, we need to add some extra file descriptors for crash handling and
   // the sandbox.
   const int crash_signal_fd =
@@ -645,7 +645,7 @@ base::ProcessHandle BrowserRenderProcessHost::ExecuteRenderer(
   const int sandbox_fd =
       Singleton<RenderSandboxHostLinux>()->GetRendererSocket();
   fds_to_map.push_back(std::make_pair(sandbox_fd, kSandboxIPCChannel + 3));
-#endif  // defined(OS_LINUX)
+#endif  // defined(OS_NIX)
 
   // Actually launch the app.
   zygote_child_ = false;
@@ -751,11 +751,11 @@ bool BrowserRenderProcessHost::FastShutdownIfPossible() {
   // On POSIX, we must additionally reap the child.
 #if defined(OS_POSIX)
   if (zygote_child_) {
-#if defined(OS_LINUX)
+#if defined(OS_NIX)
     // If the renderer was created via a zygote, we have to proxy the reaping
     // through the zygote process.
     Singleton<ZygoteHost>()->EnsureProcessTerminated(process_.handle());
-#endif  // defined(OS_LINUX)
+#endif  // defined(OS_NIX)
   } else {
     ProcessWatcher::EnsureProcessGetsReaped(process_.handle());
   }
@@ -787,9 +787,9 @@ TransportDIB* BrowserRenderProcessHost::MapTransportDIB(
   // On OSX, the browser allocates all DIBs and keeps a file descriptor around
   // for each.
   return widget_helper_->MapTransportDIB(dib_id);
-#elif defined(OS_LINUX)
+#elif defined(USE_X11)
   return TransportDIB::Map(dib_id);
-#endif  // defined(OS_LINUX)
+#endif  // defined(USE_X11)
 }
 
 TransportDIB* BrowserRenderProcessHost::GetTransportDIB(
@@ -925,7 +925,7 @@ void BrowserRenderProcessHost::OnChannelConnected(int32 peer_pid) {
       //      it's PID is 2 or 3.
       // Additionally, this check isn't a security problem on Linux since we
       // don't use the PID as reported by the renderer.
-#if !defined(OS_LINUX)
+#if !defined(OS_LINUX) && !defined(OS_FREEBSD)
       CHECK(peer_pid == process_.pid()) << peer_pid << " " << process_.pid();
 #endif
     }
@@ -966,7 +966,7 @@ void BrowserRenderProcessHost::OnChannelError() {
     did_crash = false;
     child_exited = true;
   } else if (zygote_child_) {
-#if defined(OS_LINUX)
+#if defined(OS_NIX)
     did_crash = Singleton<ZygoteHost>()->DidProcessCrash(
         process_.handle(), &child_exited);
 #else
diff --git chrome/browser/renderer_host/mock_render_process_host.cc chrome/browser/renderer_host/mock_render_process_host.cc
index 55fd014..cc52669 100644
